@@ -1,9 +1,9 @@
 /*!
- * Copyright (c) 2019-2020 by Contributors
+ * Copyright (c) 2019-2021 by Contributors
  * \file dump.cc
  * \brief Generate text representation of AST
  */
-#include <dmlc/registry.h>
+#include <treelite/logging.h>
 #include "./builder.h"
 
 namespace {
@@ -13,7 +13,7 @@ void get_dump_from_node(std::ostringstream* oss,
                         int indent) {
   (*oss) << std::string(indent, ' ') << node->GetDump() << "\n";
   for (const treelite::compiler::ASTNode* child : node->children) {
-    CHECK(child);
+    TREELITE_CHECK(child);
     get_dump_from_node(oss, child, indent + 2);
   }
 }
@@ -23,8 +23,6 @@ void get_dump_from_node(std::ostringstream* oss,
 namespace treelite {
 namespace compiler {
 
-DMLC_REGISTRY_FILE_TAG(dump);
-
 template <typename ThresholdType, typename LeafOutputType>
 std::string
 ASTBuilder<ThresholdType, LeafOutputType>::GetDump() const {
