@@ -303,6 +303,7 @@ class LearnerParamHandler : public OutputHandler<treelite::ModelImpl<float, floa
 
 struct XGBoostModelHandle {
   treelite::ModelImpl<float, float>* model;
+  std::vector<unsigned> version;
   std::string objective_name;
 };
 
@@ -318,6 +319,14 @@ class LearnerHandler : public OutputHandler<XGBoostModelHandle> {
   std::string objective;
 };
 
+/*! \brief handler for XGBoost checkpoint */
+class XGBoostCheckpointHandler : public OutputHandler<XGBoostModelHandle> {
+ public:
+  using OutputHandler<XGBoostModelHandle>::OutputHandler;
+  bool StartArray() override;
+  bool StartObject() override;
+};
+
 /*! \brief handler for XGBoostModel objects from XGBoost schema */
 class XGBoostModelHandler : public OutputHandler<XGBoostModelHandle> {
  public:
@@ -325,9 +334,6 @@ class XGBoostModelHandler : public OutputHandler<XGBoostModelHandle> {
   bool StartArray() override;
   bool StartObject() override;
   bool EndObject(std::size_t memberCount) override;
-
- private:
-  std::vector<unsigned> version;
 };
 
 /*! \brief handler for root object of XGBoost schema*/
@@ -343,14 +349,18 @@ class RootHandler : public OutputHandler<std::unique_ptr<treelite::Model>> {
 class DelegatedHandler
     : public rapidjson::BaseReaderHandler<rapidjson::UTF8<>, DelegatedHandler>,
       public Delegator {
-
  public:
-  /*! \brief create DelegatedHandler with initial RootHandler on stack */
-  static std::shared_ptr<DelegatedHandler> create() {
+  /*! \brief create DelegatedHandler with empty stack */
+  static std::shared_ptr<DelegatedHandler> create_empty() {
     struct make_shared_enabler : public DelegatedHandler {};
-
     std::shared_ptr<DelegatedHandler> new_handler =
       std::make_shared<make_shared_enabler>();
+    return new_handler;
+  }
+
+  /*! \brief create DelegatedHandler with initial RootHandler on stack */
+  static std::shared_ptr<DelegatedHandler> create() {
+    std::shared_ptr<DelegatedHandler> new_handler = create_empty();
     new_handler->push_delegate(std::make_shared<RootHandler>(
       new_handler,
       new_handler->result));
